==> rdatapp-0.7.tar.gz: rdatapp-0.7/setup.py <==
from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='rdatapp',
    version='0.7',
    packages=find_packages(),
    install_requires=[
        'pandas',
        'numpy',
        'scikit-learn',
        'nltk',
    ],
    description='A recoded data preprocessing library for handling various data cleaning and transformation tasks. The library includes classes for text cleaning, missing value imputation, one-hot encoding, and more.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Izzettin Furkan Özmen, Ismail Cifci',
    author_email='izzettinfurkan.ozmen@stu.fsm.edu.tr, ismail.cifci@stu.fsm.edu.tr',
    url='https://github.com/Beegash/Recoded-Data-Processing-Library',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Scientific/Engineering :: Information Analysis',
    ],
    python_requires='>=3.6',
    keywords='data preprocessing data-cleaning one-hot-encoding text-cleaning missing-value-imputation',
    project_urls={
        'Source': 'https://github.com/Beegash/Recoded-Data-Processing-Library',
    },
)

==> rdatapp-1.0.tar.gz: rdatapp-1.0/setup.py <==
from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='rdatapp',
    version='1.0',
    packages=find_packages(),
    install_requires=[
        'pandas',
        'numpy',
        'scikit-learn',
        'nltk',
    ],
    description='A recoded data preprocessing library for handling various data cleaning and transformation tasks. The library includes classes for text cleaning, missing value imputation, one-hot encoding, and more.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Izzettin Furkan Özmen, Ismail Cifci',
    author_email='izzettinfurkan.ozmen@stu.fsm.edu.tr, ismail.cifci@stu.fsm.edu.tr',
    url='https://github.com/Beegash/Recoded-Data-Processing-Library',
    classifiers=[
        'Development Status :: 6 - Mature',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Scientific/Engineering :: Information Analysis',
    ],
    python_requires='>=3.6',
    keywords='data preprocessing data-cleaning one-hot-encoding text-cleaning missing-value-imputation',
    project_urls={
        'Source': 'https://github.com/Beegash/Recoded-Data-Processing-Library',
    },
)
